
# Type: child of named thing




URI: [https://example.com/test65/ChildOfNamedThing](https://example.com/test65/ChildOfNamedThing)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[NamedThing]^-[ChildOfNamedThing&#124;subject:string%20%3F])

## Parents

 *  is_a: [NamedThing](NamedThing.md)

## Referenced by class


## Attributes


### Own

 * [child of named thing➞subject](child_of_named_thing_subject.md)  <sub>OPT</sub>
    * range: [String](types/String.md)

### Domain for slot:

 * [child of named thing➞subject](child_of_named_thing_subject.md)  <sub>OPT</sub>
    * range: [String](types/String.md)
